@@ -16,5 +16,5 @@ class CampaignStatus(Enum):
 class Campaign(UserFacingDataType):
     name: str
     status: CampaignStatus
-    campaign_sequence_id: str
+    sequence_id: str
     replenish: bool
