@@ -38,3 +38,5 @@ class CampaignLogEvent(UserFacingDataType):
     thread_id: Optional[str] = None
     sequence_step_id: Optional[str] = None
     recommendation_id: Optional[str] = None
+    email_subject: Optional[str] = None
+    email_body: Optional[str] = None
