@@ -125,7 +125,7 @@ class Person(IngestedDataType):
     industry: Optional[str] = None
     company_id: Optional[str] = None
     job_title: Optional[str] = None
-    canonical_job_titles: Optional[CanonicalJobTitle] = None
+    canonical_job_titles: Optional[list[CanonicalJobTitle]] = None
     job_title_levels: Optional[list[str]] = None
     job_role_description: Optional[str] = None
     job_start_date: Optional[str] = None
