@@ -14,10 +14,12 @@ class RecommendationStatus(Enum):
     PENDING = 'PENDING'
 
 
-# TODO: iterate on these field values
 class RecommendationRejectionReason(Enum):
+    NOT_RELEVANT = 'NOT_RELEVANT'
+    WRONG_POSITION_RIGHT_COMPANY = 'WRONG_POSITION_RIGHT_COMPANY'
+    RIGHT_POSITION_WRONG_COMPANY = 'RIGHT_POSITION_WRONG_COMPANY'
     EXISTING_CUSTOMER = 'EXISTING_CUSTOMER'
-    NOT_QUALIFIED = 'NOT_QUALIFIED'
+    ALREADY_CONTACTED = 'ALREADY_CONTACTED'
     OTHER = 'OTHER'
 
 
@@ -29,3 +31,4 @@ class Recommendation(UserFacingDataType):
     status: RecommendationStatus
     relevance: float
     rejection_reason: Optional[RecommendationRejectionReason] = None
+    free_text_rejection_reason: Optional[str] = None
